@@ -1,7 +1,9 @@
 """Annotations for marking-up reference implementations"""
 
 from . import invariants
-from .annotation import Annotation, AnnotationResult
+from .annotation import *
+from .collection import *
 from .complexity import *
 from .relation import *
+from .type_ import *
 from .value import *
